import { SummaryObject } from './latency-monitor.js';
import type { AbortOptions } from '@libp2p/interfaces';
import { EventEmitter } from '@libp2p/interfaces/events';
import type { Startable } from '@libp2p/interfaces/startable';
import { PeerId } from '@libp2p/interface-peer-id';
import type { Connection, MultiaddrConnection } from '@libp2p/interface-connection';
import type { ConnectionManager, ConnectionManagerEvents, Dialer } from '@libp2p/interface-connection-manager';
import type { PeerStore } from '@libp2p/interface-peer-store';
import { Multiaddr } from '@multiformats/multiaddr';
import type { Metrics } from '@libp2p/interface-metrics';
import type { Upgrader } from '@libp2p/interface-transport';
import type { ConnectionManagerConfig } from '../index.js';
export interface DefaultConnectionManagerComponents {
    peerId: PeerId;
    metrics?: Metrics;
    upgrader: Upgrader;
    peerStore: PeerStore;
    dialer: Dialer;
}
export type ConnectionManagerInit = Required<ConnectionManagerConfig>;
/**
 * Responsible for managing known connections.
 */
export declare class DefaultConnectionManager extends EventEmitter<ConnectionManagerEvents> implements ConnectionManager, Startable {
    private readonly components;
    private readonly opts;
    private readonly connections;
    private started;
    private readonly latencyMonitor;
    private readonly startupReconnectTimeout;
    private connectOnStartupController?;
    private readonly dialTimeout;
    private readonly allow;
    private readonly deny;
    private readonly inboundConnectionRateLimiter;
    private incomingPendingConnections;
    constructor(components: DefaultConnectionManagerComponents, init: ConnectionManagerConfig);
    isStarted(): boolean;
    /**
     * Starts the Connection Manager. If Metrics are not enabled on libp2p
     * only event loop and connection limits will be monitored.
     */
    start(): Promise<void>;
    afterStart(): Promise<void>;
    beforeStop(): Promise<void>;
    /**
     * Stops the Connection Manager
     */
    stop(): Promise<void>;
    /**
     * Cleans up the connections
     */
    _close(): Promise<void>;
    onConnect(evt: CustomEvent<Connection>): void;
    /**
     * Tracks the incoming connection and check the connection limit
     */
    _onConnect(evt: CustomEvent<Connection>): Promise<void>;
    /**
     * Removes the connection from tracking
     */
    onDisconnect(evt: CustomEvent<Connection>): void;
    getConnections(peerId?: PeerId): Connection[];
    openConnection(peerIdOrMultiaddr: PeerId | Multiaddr, options?: AbortOptions): Promise<Connection>;
    closeConnections(peerId: PeerId): Promise<void>;
    /**
     * Get all open connections with a peer
     */
    getAll(peerId: PeerId): Connection[];
    /**
     * If the event loop is slow, maybe close a connection
     */
    _onLatencyMeasure(evt: CustomEvent<SummaryObject>): void;
    /**
     * If the `value` of `name` has exceeded its limit, maybe close a connection
     */
    _checkMaxLimit(name: keyof ConnectionManagerInit, value: number, toPrune?: number): Promise<void>;
    /**
     * If we have more connections than our maximum, select some excess connections
     * to prune based on peer value
     */
    _pruneConnections(toPrune: number): Promise<void>;
    acceptIncomingConnection(maConn: MultiaddrConnection): Promise<boolean>;
    afterUpgradeInbound(): void;
}
//# sourceMappingURL=index.d.ts.map